@@ -1,6 +1,6 @@
 """Template class for a Transformer Algorithm
 """
-from environment import Environment
+from agpytesting.environment import Environment
 
 
 class Algorithm:
